;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xc45867f2af4b63643ec618561ddad87e . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xc5384a4a05b4887af76044dce46a56a3 . "./code.cg2js/cg-printing.fasl")
(#xc19b6815f637aa016c6b8ec209e3fffc . "./code.cg2js/cg-caret.fasl")
(#x9f9a7470bfbc3092c9eb0e03dad17857 . "./code.cg2js/cg-item-list.fasl")
(#xc28b7c92514868dfbcb49a843684eb0c . "./code.cg2js/cg-progress-indicator.fasl")
(#x9e1ff83eb2b1ba73a867aa36e4196942 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x3babfe2faa3c068b83a6b238a6f75098 . "./code.cg2js/cg-outline.fasl")
(#x4481f50a8d0c0d50c623d30fd9cf27f4 . "./code.cg2js/cg-palette.fasl")
(#x778475c4fc6086133ad382f7f1600e2b . "./code.cg2js/cg-selected-object.fasl")
(#x66c79ad4c91af25363968e5a70543771 . "./code.cg2js/cg-status-bar.fasl")
(#x319ffe312fff9dcfcb47e54c365947a1 . "./code.cg2js/cg-wrap-string.fasl")
(#x3ff107019b9db47aae8106c1783ec853 . "./code.cg2js/cg-fill-texture.fasl")
(#x5e226bbef1a61ed7147d7e3c1ade8aba . "./code.cg2js/cg-layout.fasl")
(#xc21edfeb6594c19da5cb60e3da12bb49 . "./code.cg2js/cg-timer.fasl")
(#x1efb1c966fe509c54bd48d1f4102497f . "./code.cg2js/cg-dialog-item.fasl")
(#x4b900ff8a01dda543c235a074335d887 . "./code.cg2js/cg-button.fasl")
(#x2fe8eb583895491a4856b949ac6a5dc9 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xedb136ec532afa968adfd19cd647d256 . "./code.cg2js/cg-tray.fasl")
(#x55b5ecca8d984dc4c73aa568e5f4c026 . "./code.cg2js/cg-plot-widget.fasl")
(#xd301f1c689c35f021f33517c568b2bae . "./code.cg2js/cg-pixmap.fasl")
(#xdf8fbf05b3e05448acafeb08adb0630e . "./code.cg2js/cg-font-dialog.fasl")
(#x4643c6c4566e70c03ba47c0f5123cdea . "./code.cg2js/cg-os-widget.fasl")
(#xaf0646a890f27b6666697dc8e6c90ce4 . "./code.cg2js/cg-text-or-combo.fasl")
(#xdb387abc1d4e74478f09925a04e6d861 . "./code.cg2js/cg-trackbar.fasl")
(#xe7b760c02472c6fca8ae0208129a6066 . "./code.cg2js/cg-up-down-control.fasl")
(#x8e987a1ffa0686b46c2b010456ae2949 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xc9acf7fb85ca824a2597e73096bece0a . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xe36013187be1634ab3a495a791a841b9 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xe8379fb4cc83765319eb97c64afe9b50 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x74c6c3e9f44de2f50bef5538bf42f346 . "./code.cg2js/cg-chart-widget.fasl")
(#x7c8616de36bf5be0284bd24539ab38e4 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x256e35524f64e727de244b63f68821aa . "./code.cg2js/cg-group-box.fasl")
(#x75c6f21211b595a1ec4feba3d65f4be4 . "./code.cg2js/cg-static-text.fasl")
(#xac3534f2f73ae18e1115a5fa2191ccd7 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x85198ceabe6bf662852cfba8b64c1895 . "./code.cg2js/cg-color-dialog.fasl")
(#x7bdad3f7e0a54d435dbb5f160b45c567 . "./code.cg2js/cg-intersect.fasl")
(#x212a1b19bbf430b251a288ff39e7b4b6 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x2558bc736c6f7e56cb57b137f68748a0 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x29f41ce2597b964989c993417721f73a . "./code.cg2js/cg-html-dialog.fasl")
(#x1a7fea9ef5820f7c512ed02d9b32047e . "./code.cg2js/cg-lettered-menu.fasl")
(#xf9b097c1e76008817f7026031fab82ca . "./code.cg2js/cg-class-grid.fasl")
(#x42fe1c0fa6ec8875c3eccce98873980b . "./code.cg2js/cg-pixmap-printing.fasl")
(#xbee0c454b7943e4462a0baf98d47fd6b . "./code.cg2js/cg-calendar.fasl")
(#x99bfa8e8061a0f0eb559cfd6bb78c7b6 . "./code.cg2js/cg-editable-text.fasl")
(#xd22e76bc57887f0d73e8e8c77428821f . "./code.cg2js/cg-property.fasl")
(#x36b574264e27e261cbe510551c01176d . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x64d484d71d06472bc159b69cc04a8e3c . "./code.cg2js/cg-grid-widget.fasl")
(#xf3fa4eacd673e04dc951933f29647be2 . "./code.cg2js/cg-paren-matching.fasl")
(#x545586287d05ceaca23e1b8a071e1626 . "./code.cg2js/cg-dev.fasl")
(#xe6bbfb75dd4b09bafd8d0f0317ce7686 . "./code.cg2js/cg-drawable.fasl")
(#x98214e843a05002ea0912392839da68c . "./code.cg2js/cg-curve.fasl")
(#x0c552684d2595bb35c88c9e1a63089e2 . "./code.cg2js/cg-lisp-widget.fasl")
(#x75751a978dcc5c46340063ac1aad9eb1 . "./code.cg2js/cg-dde-utils.fasl")
(#xd85575d18ff9a82f5fdcaafb8a2fe55d . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xf11e0d223ac5d94dd020d628ee47b032 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xbbe1ddb915b229ebeee9e6d43bd5dfdd . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x48567773c781cfb9ad81fa6ee0599cd7 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xb8af51813e7a3dd78b4302f90b542806 . "./code.cg2js/cg-lamp.fasl")
(#x1cb318974d2bffd22eae152892de1bdb . "./code.cg2js/cg-common-control.fasl")
(#x39df41c6b819e58a2714bd25491ae8ff . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x2431531be5b808b18d884d8553e7b3fd . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x8907e3411910b0fe7ce023dae0f6b557 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xdc1b565c1fba164284db130ece8f545b . "./code.cg2js/cg-project-window.fasl")
(#xf057ed994079c2b7eb90cb4259c9e3ec . "./code.cg2js/cg-sample-file-menu.fasl")
(#x800568507b85acce6fe1db74d222235f . "./code.cg2js/cg-class-support.fasl")
(#x5abf759790ecc18065d36fc1f5b30c5b . "./code.cg2js/cg-multi-picture-button.fasl")
(#xfd013a8cc6121262d665377e64dd4b58 . "./code.cg2js/cg-yes-no-list.fasl")
(#x061f36aaa54e15ee7a76aaeaf1166951 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x4e471f9e0ff87421726230fe1949a7eb . "./code.cg2js/cg-string-dialog.fasl")
(#x74a0e030a524aa32bf20c38f182fd650 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x56da188b4a1a12bc63607e8bff719a98 . "./code.cg2js/cg-dropping-outline.fasl")
(#x1b7802d6af3613283175e80ced097d42 . "./code.cg2js/cg.fasl")
(#xca6b84537ac4d9e712820a3c39c011bf . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x4382722a5a41c36cc71329d34b46c55b . "./code.cg2js/cg-scaling-stream.fasl")
(#x316137cdad4709a17ffcca86d3409c48 . "./code.cg2js/cg-yes-no-string.fasl")
(#xe0ea0b502e357563bb5704f07f26d71b . "./code.cg2js/cg-icon-pixmap.fasl")
(#xbc2c93673cf928d6a7890fa40d50ee0d . "./code.cg2js/cg-web-browser.fasl")
(#x9856d73bd1ad833715ca1497f6de8377 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x32af831112858205cbdbae685740027c . "./code.cg2js/cg-drag-and-drop.fasl")
(#x741170dfa4798a0d42a417023a249499 . "./code.cg2js/cg-message-dialog.fasl")
(#xb6d197fd5b1db116d890e8b38b2ff9ce . "./code.cg2js/cg-comtab.fasl")
(#xf7c011260ebaf95b7a9fb76b42ad14fb . "./code.cg2js/cg-base.fasl")
(#x3e747e6db295dc7701b794e87c050c12 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x43c577179caafc046a2d7723395bd3c9 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x1810c66667003ab0ecd92c262cc478a7 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xe35bbfd8875c1e1b3f21d36b34bc0c6a . "./code.cg2js/cg-utility-dialog.fasl")
(#xfa0838467a1a76af7e2eb176761fd067 . "./code.cg2js/cg-object-editor.fasl")
(#xbe2c93ce77e27625c5f3af3405370b86 . "./code.cg2js/cg-edit-in-place.fasl")
(#xe416e6900e61022fd9a28eb6032be8b7 . "./code.cg2js/cg-radio-button.fasl")
(#xb5e4fbd27775883e5ac22c48f10181f5 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x13fb1537b17784edc6fa9b5deb6fc463 . "./code.cg2js/cg-nodes.fasl")
(#x078fd9b5c0ada557da3820cb0393db56 . "./code.cg2js/cg-get-position.fasl")
(#x5b63255172497b6095c934afbe214017 . "./code.cg2js/cg-directory-dialog.fasl")
(#xf7791c505462e91d061dba213fea130c . "./code.cg2js/cg-lisp-text.fasl")
(#xd54c78a8d78113144413212d0a5ea336 . "./code.cg2js/cg-combo-box.fasl")
(#xf43c7c6c3b67ceddb4a5850030acceba . "./code.cg2js/cg-text-widget.fasl")
(#xb0368db1e89b355ebe44a5dc0e55a629 . "./code.cg2js/cg-list-view.fasl")
(#x448e2ae25ae39a0560aeb6cb200464d8 . "./code.cg2js/cg-header-control.fasl")
(#xd659a326924e11562c1b6597f04c3d56 . "./code.cg2js/cg-graphics-context.fasl")
(#x29d395a999ac3168d32e70d34729e579 . "./code.cg2js/cg-get-pixmap.fasl")
(#x02352557df48fd37a2ffe1b0f5e1fa2c . "./code.cg2js/cg-menu.fasl")
(#xed8a098059e42e5318470bf8717ba196 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xf0f3e09517a23c48ca39ebc6a4cdc142 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xbd8b1aee074f0ba1e0c2e91682ea721e . "./code.cg2js/cg-tooltip.fasl")
(#x70499239b6a1236dcd9e004c0ea05e54 . "./code.cg2js/cg-html-widget.fasl")
(#x3e6e01cd188e963a6bab6adaa3f37f77 . "./code.cg2js/cg-choice-list.fasl")
(#x9c9297f0d05def18105d48e90640e0bc . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xfb2d7d658d334d8120d6e737e8ca4160 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x6e4a4874e95201866d65a5018cd4c0f0 . "./code.cg2js/cg-icon.fasl")
(#x7e87ca30e39e26067a7f93e857ddc6ae . "./code.cg2js/cg-acache.fasl")
(#x3262aa5b41f3416b1529269947d7987b . "./code.cg2js/cg-template-string.fasl")
(#xf58a93850a5044eb3fbee8081f7cf506 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x7f77658e55a00db9b2a5ef911d3ca80b . "./code.cg2js/cg-toggling-widget.fasl")
(#x5925d47a9157a246bce3556bd55629a8 . "./code.cg2js/cg-tab-control.fasl")
(#xb3ddf42f716393eb5e5ae6cc56c6253d . "./code.cg2js/cg-split-bar.fasl")
(#x8318e74afbd7f32e4e20a16f143ca947 . "./code.cg2js/cg-picture-widget.fasl")
(#x6068f714dba31c28cece6380d4e30ce6 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#xee7441fc8191dfa66e44e5f03f8c89b2 . "./code.cg2js/cg-choose-printer.fasl")
(#x3d22392da1317fa465b1929a667bfee4 . "./code.cg2js/cg-os-window.fasl")
(#x1e97cba4a5915e9580084699b9c89c99 . "./code.cg2js/cg-scroll-bar.fasl")
(#xa814d5a7f4cbb786f4f8b5e8f9445c65 . "./code.cg2js/cg-clipboard.fasl")
(#x6650d22c8515acc85192a46f29f7468e . "./code.cg2js/cg-find-string-dialog.fasl")
(#xd8b121dbf74e39069009c539cd6df0c4 . "./code.cg2js/cg-hotspot.fasl")
(#x36a17a7effcf6d133556fc065f31a1a9 . "./code.cg2js/cg-rich-edit.fasl")
(#x5b66b423a69aea62727eb7b9a92fedd2 . "./code.cg2js/cg-check-box.fasl")
(#xf2eecef99b3628102cdf0902cd293bd0 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x86fcf2404d1be1c176f92afa93625197 . "./code.cg2js/cg-file-dialog.fasl")
(#x75e8d8b9e803c11a1461a6db469517c3 . "./code.cg2js/cg-toolbar.fasl")
(#x32cd6b26a6e9bbf8624b3cb4ccc7eda5 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x7e1d9e627dbbcd02e867e18873694e3f . "./code.cg2js/cg-chart-or-plot.fasl")
(#x96c42373a2c982bdd4e026f86e7531cf . "./code.cg2js/cg-shortcut-menu.fasl")
(#x21c5afe651b985f35fa7dcd1e70cb941 . "./code.idejs/ide-project.fasl")
(#xdf62e254f1d520cdc6db70856137c917 . "./code.idejs/ide-intro.fasl")
(#x93a2597d68ee8427741dea38154b5406 . "./code.idejs/ide-find-in-files.fasl")
(#xfa83886e7e0e8a149e20c135723ae462 . "./code.idejs/ide-grapher.fasl")
(#x370f2f8eef1237646184cf2b15172515 . "./code.idejs/ide-inspector.fasl")
(#x75de4dfda9bbef395ede42e8433c1235 . "./code.idejs/ide-editor.fasl")
(#xd69e53ce8499e5a78c159c110805fc5e . "./code.idejs/ide-window-list.fasl")
(#x33d31e7e7cf6cca39836190a44b108b9 . "./code.idejs/ide-process-browser.fasl")
(#xa686ab3f578b3d21a9ea3c74f2145581 . "./code.idejs/ide-patch-dialog.fasl")
(#x5558f241b523982d174fd3594d7c7852 . "./code.idejs/ide-class-grapher.fasl")
(#xb804f1ad8da4f182349a299b63ef97f9 . "./code.idejs/ide-base.fasl")
(#x993b14b8329ca50b77bf4c806b20af62 . "./code.idejs/ide.fasl")
(#xba353ffb4e6a39cf3aed1bd5568def48 . "./code.idejs/ide-trace.fasl")
(#x724225c683a959e53fd42081583792c5 . "./code.idejs/ide-form.fasl")
(#x587e832490d16c82f9f7065c7c6b4927 . "./code.idejs/ide-find-definitions.fasl")
(#x339e545c34781f4867137bc6916103f8 . "./code.idejs/ide-apropos.fasl")
(#x91295c184620ad1c6b738dd4ae8440d1 . "./code.idejs/ide-class-browser.fasl")
(#xa7530bd61ee4ff6105240c54094a74ee . "./code.idejs/ide-navigator.fasl")
(#x71c342daf550807b9554d8f9e27320de . "./code.idejs/ide-clipboard.fasl")
(#x059b1a3e8109d15b6eb7ae206f7a8e28 . "./code.idejs/ide-acache.fasl")
(#xc620070418e789bc3adf66dc8c790c96 . "./code.idejs/ide-keyshort.fasl")
(#x7e9113258178f5118863fa9dd7393844 . "./code.idejs/ide-package-list.fasl")
(#x4262aeaf74bbbdb68f9dff50b16bcb0e . "./code.idejs/ide-dev.fasl")
(#xe396744af4d34e05e734175c54f8cafc . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
